+++
title = "How to Make a Healthier Nation of Omnivores"
description = "The government should give to small farms by cutting regulation and raising food prices while taxing big agriculture to help low-income households afford good food."

[taxonomies]
categories = ["projects", "blog"]
tags = ["farming", "politics", "nature"]

[extra]
zenn_applause = true
+++

At my family’s small lowbush blueberry farm in late July and early August, the energy is festive. Over a thousand customers come from around the valley with their friends and small children each year to participate in harvesting the year’s blueberries, and most of them have a personal connection to the farm and the land, if not to my family directly. The blueberry sorting barn is filled with the roaring of fans and conveyor belts as the fruit is winnowed and packaged into boxes of five, ten, or twenty pounds and sold directly a few yards away; out in the picturesque fields, customers pick their own berries alongside local teenagers harvesting thousands of pounds of blueberries each day for what is often their very first job. The fruit is firm and sweet, easily surpassing in quality the conventionally grown lowbush blueberries, usually from Canada or Maine, found in the frozen section at supermarkets; and healthy-minded mothers excitedly discuss the antioxidant properties of the lowbush variety while tussling the blueberry-stained hair of their toddlers.

<!-- more -->

Small farms like this one are good for society, as contributors to the community and as producers of sustenance. They are better for the environment, often using less energy from outside sources, employing sustainable agricultural methods like crop rotation, rotational grazing, minimal pesticide application, and providing humane conditions for healthy animals (Andrée 16) (Haspel). They are more likely to act as carbon sinks than as net emitters when compared to their larger counterparts (Andrée 16). Their food is usually fresher and healthier, and they usually grow diverse crops of fruits and vegetables instead of monocrops of corn and soy (Haspel). Additionally, as Tamar Haspel wrote for the Washington Post, “there’s value in having a place where people can take kids to pull a carrot out of the ground or come face to face with a pig,” and virtually everyone agrees with this.

These correlations between good farming practices and farm size aren’t just correlations; there is real cause and effect going on. On small farms, both consumers and farm owners have a more direct connection to the land, and their decisions will thus more closely reflect the best interests of the land and the earth instead of their financial situation. While large farms act as maximum efficiency crop producing engines, small farms are more often managed in ways that are best for the long term.

As Haspel also writes, it is an accepted fact that small farms are struggling to survive. Because of the economy of scale, large farms are inherently more efficient, and when this plays out in the market, small farms’ share of food production falls: from 1991 to 2017, it was cut almost in half (Semuels). Farm debt is at an all-time high, and the majority of small farms don’t sell even $10,000 worth of food annually (Semuels) (Haspel). Over half the world’s hungry are small-scale agriculturalists, and if they can’t make enough to get by, many say, it seems highly dubious that small farms could come close to feeding the world (Andrée 16).

The financial failures of America’s small farms, however, are by no means insurmountable. Those who point to the high numbers of financially impractical small farms as a reason they cannot be the vision for agriculture’s future forget that their struggles are in large part a result of government policy: poorly thought out regulations designed for industrial scale agriculture, large subsidies given primarily to the biggest farms, and the abandonment of New Deal style price floors (laws which set the minimum price a product could be legally sold for) (Andrée 16) (Bittman) (Semuels). It is true that most farms must be large enough to supply local retailers and to turn a profit; but the first requirement isn’t a very high threshold (my family’s thirty-six acre farm meets it easily), and there are new promising policies the government could implement that would result in financial viability for small farms and generate strength, prosperity, and health in communities nationwide.

The health and building codes’ regulation of small farms must be drastically reduced. Rod Dreher and Peter Andrée detail how illogical regulations hurt farmers by forcing them to slaughter and process their animals in federally inspected abattoirs no matter where or how the meat will be sold. These regulations are necessary for industrial scale meat processors, but outbreaks of E. coli or listeria are not a concern for small farmers who are processing the meat that they raised and are selling directly to consumers (Andrée 17) (Dreher). In some regions, it is illegal to sell meat or eggs from poultry raised outdoors because of concerns about the avian flu, a phenomenon primarily associated with industrial factory farms (Andrée 16). In Virginia, the famous farmer and activist Joel Salatin had to put designated bathrooms and lockers for employees into his inspected meat processing facility even though he had no employees (Dreher 26). And on my family’s farm here in Massachusetts, laws regulating the transportation of frozen food, the disposal of dairy wastewater, and other important and consideration-worthy issues have nevertheless placed roadblocks to our business in ridiculous and illogical ways for which they were not meant.

There are several key ways regulations on small farmers should be lifted to promote their growth while protecting the public health. Direct farmer to consumer sales should be mostly or completely deregulated, and restrictions on indirect sales should be loosened. Constitutional clauses like the failed [LD 783](https://legislature.maine.gov/legis/bills/display_ps.asp?LD=783&snum=127) of Maine should become endorsed by the U.S. Food and Drug Administration, protecting the “Right to Food” by preventing regulation of homemade direct-sales food. In the meantime, municipalities should be given the option to enact town-specific bylaws declaring “food sovereignty” which allow the direct on-site sale of food without regulation (this has been granted in Maine only to be gutted by threats from the USDA), and food sovereignty laws should be extended to include products sold at farmers’ markets (Gaulkin). Licenses for small meat processing facilities, on the other hand, should still be required for wholesalers, but they should be controlled by municipalities or states when those bodies choose to declare sovereignty, and they should be centered around a dogma of placing minimum burden on small farmers while maintaining food safety. Additionally, restrictions on non-meat wholesale transactions should be loosened for small farmers selling to local stores. This can be done especially in rural areas where the retailer is locally positioned relative to the farm because any irresponsible behavior on the part of the farmer would be kept in check by direct relationships with the consumers of the area.

In addition to desisting as much as possible from active interference with small farms, the government should incentivize buying sustainably grown food. If small farms were deregulated in these ways, many more of them would likely become profitable and expand into growing new crops and livestock for their communities. But the economy of scale would mean that large conventionally managed agribusinesses would still be able to charge far less for their food than small, sustainable growers, and as cost is the single most important purchasing influencer for food buyers, small farms would still be outcompeted (Ni Mhurchu et al.). So in order to truly promote the well being of small farms, the government must economically intervene to level the playing field. There are a myriad of ways this could be done, from direct guaranteed government paychecks to these farms to purchasing and reselling food at a loss in order to guarantee a price floor for farmers while keeping the costs low for consumers. Every option has benefits and drawbacks; the one I argue is best tackles several issues simultaneously.

The best way for the government to support small farmers is through giving purchasing power to consumers. The problem the government must address is one of equalizing food prices. In order for this to happen, either small farms must lower their prices, or large farms must raise their prices. Although many do not like the idea of raising food prices, in this country the majority of people can afford to spend more on food than they do now: in 2019, American’s spent a smaller share of their incomes on food than ever before, down almost 50 percent from 1960 (USDA). If the government taxed agribusiness heavily, they would be forced to raise their prices, allowing small farms to do the same without being outcompeted. Expanded welfare programs could enable those who cannot afford an increase in food spending to support small sustainably managed farms through greatly expanding programs like the federal government’s SNAP benefits and Massachusetts' Healthy Incentives Program. Under this system, small farms could become authorized incentives program vendors, enabling them to accept the incentive dollars from low-income shoppers who would receive a monthly credit to spend through the program. This kind of program is known to be realistic, as versions of it have already been implemented, and effective, as has been shown in practice and through studies (Commonwealth of Massachusetts) (Ni Mhurchu et al.).

One challenge to be faced if this were implemented would involve ensuring that the vast majority of eligible farms sign on to start accepting the incentives. This could be accomplished through one-time monetary rewards to farms when they sign up, as well as the promotion of the program through advertising and educational initiatives. Once a critical mass of small farms began to participate, the rest would be pushed to follow by competition, and the monetary rewards could be discontinued. Another challenge would be transitioning to increased levels of direct sales in cities, where food must be transported further from farm to table. This could be addressed through systems like sellers’ cooperatives, where many small farms own one supermarket together, so prices are raised only minimally and incentive dollars could still be accepted. Distribution could also be handled by third parties though schemes like the UK’s food box system, which are essentially scaled-up CSAs incorporating many small farms into one delivery system (Andrée 17).

The raising of food prices and preferential treatment for small agriculture would be a complete overhaul of the agricultural economy, but the benefits would be widespread and deep-reaching, accomplishing much more than saving struggling small farmers. First, it would maintain a more competitive environment than direct payments to farms because consumers would still be deciding which farms to support. Businesses with poor quality produce or bad customer service would therefore be held accountable. Second, more people would buy directly from farmers, ensuring that more of their money would directly support agriculture (instead of middlemen), and strengthening consumers’ connection to their food and the land it is grown on. Third, both the middle and upper classes would spend a percentage of their money on food that is closer to what low income families spend now, leading Americans to value food more and hopefully waste less. Finally, everyone across class boundaries would be able to eat healthier food, reducing health care costs for the country and improving quality of life across the board. The government could spend the tax money from big agriculture, as well as what that they already spend on subsidies for agribusiness, on programs that benefit us all: research for long term sustainability, including exploring ways to produce food from non-arable land; conservation of farmland threatened by development; and, of course, the expanded food assistance and incentives programs (Bittman).

These policies are not meant to end large-scale, super-efficient food production. Rather, they would force these businesses to charge more in order to benefit smaller farms. Large operations would remain profitable, as increased prices would compensate for increased taxation, and further government policies could assist them in transitioning to more sustainable farming practices.

In a country with flourishing small farms, fed by healthy locally grown food, supported by an empowered USDA and FDA, and where the poor are secure in their access not only to enough food but to high quality food, carbon emissions would be cut, health issues would decline, inequality would decrease, and quality of life would rise. This would all be accomplished simply by removing unnecessary regulations, raising taxes on large farming corporations, and expanding popular social programs which already exist. These reforms or variations on them must be added to the ever-growing list of powerful, common sense legislation on the progressive agenda, alongside election reform, single-payer healthcare, and aggressive action on climate change and inequality. Then, as grassroots action eats away at the power of lobbyists and the status quo, we can start a transition to a healthier, more resilient nation of omnivores.

Annotated Bibliography

Andrée, Peter. “Growing Right.” _Alternatives Journal (AJ) - Canada’s Environmental Voice_, vol. 35, no. 1, Feb. 2009, pp. 14-17.

Peter Andrée, organic vegetable grower and environmental politics professor from Carleton University in Ottawa, argues that while it may be impractical and undesirable to feed the world exclusively with small-scale agriculture, the prosperity of small farms has positive ecological, economic, and social impacts, and calls for the preferential treatment of small-scale growers, the elimination of illogical regulations designed for industrial scale agriculture, and the development of efficient distribution systems such as the UK’s “food-box schemes” that allow small farms to reach more customers.

Bittman, Mark. “Don't End Agricultural Subsidies, Fix Them.” _The New York Times_, 2 March 2011, [https://opinionator.blogs.nytimes.com/2011/03/01/dont-end-agricultural-subsidies-fix-them/](https://opinionator.blogs.nytimes.com/2011/03/01/dont-end-agricultural-subsidies-fix-them/).

Mark Bittman’s opinion piece argues that the government should subsidize healthy food like fruit and vegetables instead of corn and soy. He calls the current federal farm subsidy system a joke, and suggests other ways the money could be used, such as funding research in sustainable agriculture, subsidizing healthy foods such as fruits and vegetables, and leveling the playing field between farms of different sizes.

Commonwealth of Massachusetts. “Healthy Incentives Program.” _Mass.gov_, March 2020, [https://www.mass.gov/service-details/healthy-incentives-program-hip-for-clients](https://www.mass.gov/service-details/healthy-incentives-program-hip-for-clients).

This page on the official Massachusetts State website describes a current program (HIP) in place which incentivizes low income families receiving supplemental nutrition assistance to join CSAs and buy fruits and vegetables from local farmers and vendors by awarding one dollar for each dollar spent on eligible produce, up to a monthly cap. The page includes an information fact sheet, a description of the program, and instructions on how to find HIP authorized retailers.

Dreher, Rod. “USDA—Disapproved.” _National Review_, vol. 55, no. 1, January 2003, pp. 24-28.

Rod Dreher, a conservative author of several books and articles and senior editor at The American Conservative, tells several stories from across the country of small farmers’ struggles with government health code regulations, and argues that these laws should be reformed to be less hurtful to small scale farms while still providing necessary protection to American consumers.

Estabrook, Barry. “The Farmers' Market Myth.” _The Atlantic_, 10 May 2011, [https://www.theatlantic.com/health/archive/2011/05/the-farmers-market-myth/238661/](https://www.theatlantic.com/health/archive/2011/05/the-farmers-market-myth/238661/).

A former contributing editor at _Gourmet_ magazine writes about studies done by Bard College's Center for Environmental Policy, the University of Seattle, and Leopold Center for Sustainable Agriculture showing that food sold at farmers’ markets is often more affordable than its supermarket counterpart.

Gaulkin, Sophia. “The Future of Maine’s Food Sovereignty Movement.” _The Regulatory Review_, Penn Program on Regulation, 14 July 2020, [https://www.theregreview.org/2020/07/14/gaulkin-future-maine-food-sovereignty-movement/](https://www.theregreview.org/2020/07/14/gaulkin-future-maine-food-sovereignty-movement/).

Gaulkin reports for the University of Pennsylvania Law School’s online journal for regulatory news about the efforts in Maine to give municipalities total control over food safety laws and the way these efforts have conflicted with the USDA and FDA.

Haspel, Tamar. “Small vs. large: Which size farm is better for the planet?” _The Washington Post_, 2 September 2014, [https://www.washingtonpost.com/lifestyle/food/small-vs-large-which-size-farm-is-better-for-the-planet/2014/08/29/ac2a3dc8-2e2d-11e4-994d-202962a9150c_story.html](https://www.washingtonpost.com/lifestyle/food/small-vs-large-which-size-farm-is-better-for-the-planet/2014/08/29/ac2a3dc8-2e2d-11e4-994d-202962a9150c_story.html).

Haspel, author of a monthly commentary on food-policy issues and oyster farmer at a small operation in Cape Cod, argues that while small farms and large farms both have benefits and drawbacks, the best solution might be to help large farms become more environmentally friendly.

Ni Mhurchu, Cliona, et al. “Economic incentives to promote healthier food purchases: exploring acceptability and key factors for success.” _Health Promotion International_, vol. 27, no. 3, September 2012, pp. 331-341. _Oxford Academic_, [https://doi.org/10.1093/heapro/dar042](https://doi.org/10.1093/heapro/dar042).

This paper by six researchers presents the results of a study evaluating the views of diverse consumers on economic incentives for healthy eating as well as the likelihood of success for these incentives. The study found that economic incentives are promising and that they were well received by the consumers in the test groups.

Semuels, Alana. “'They're Trying to Wipe Us Off the Map.' Small American Farmers Are Nearing Extinction.” _TIME_, 27 November 2019, [https://time.com/5736789/small-american-farmers-debt-crisis-extinction/](https://time.com/5736789/small-american-farmers-debt-crisis-extinction/).

Alana Semuels writes about the nationwide financial struggles of small farmers, telling the stories of individual farms like the Rieckmann family’s dairy operation as well as discussing overall trends in the industry. She explores the causes of the decline in prosperity for small farmers, pointing to the abandonment of New Deal style price floors that began in the 1970s.

USDA. “Americans’ budget share for total food was at a historical low of 9.5 percent in 2019.” _United States Department of Agriculture Economic Research Service_, 15 June 2020, [https://www.ers.usda.gov/data-products/chart-gallery/gallery/chart-detail/?chartId=76967](https://www.ers.usda.gov/data-products/chart-gallery/gallery/chart-detail/?chartId=76967).

A chart from the USDA’s Economic Research Service shows that from 1960 to 2019, the share of the American income spent on food fell from 17 percent to 9.5 percent. This is a 44 percent decrease.